import { IContributionScope, IContributions, Evaluated, IContributionUnsubscribable } from '../contributions';
import { Observable } from 'rxjs';
import { IContributionsEntry } from '../contributions';
export interface IContributionRegistry {
    /**
     * Register contributions and return an unsubscribable that deregisters the contributions.
     * Any expressions in the contributions need to be already parsed for fast re-evaluation.
     */
    registerContributions(entryToRegister: IContributionsEntry): IContributionUnsubscribable;
    /**
     * Deregister contributions
     * @param entryToDeregister
     */
    deregisterContributions(entryToDeregister: IContributionsEntry): boolean;
    /**
     * Atomically deregister the previous contributions and register the next contributions. The registry's observable
     * emits only one time after both operations are complete (instead of also emitting after the deregistration
     * and before the registration).
     */
    replaceContributions(previous: IContributionUnsubscribable, next: IContributionsEntry): IContributionUnsubscribable;
    /**
     * Returns an observable that emits all contributions (merged) evaluated in the current model
     * (with the optional scope). It emits whenever there is any change.
     *
     * @template T Extra allowed property value types for the {@link Context} value. See
     * {@link Context}'s `T` type parameter for more information.
     * @param scope The scope in which contributions are fetched. A scope can be a sub-component of
     * the UI that defines its own context keys, such as the hover, which stores useful loading and
     * definition/reference state in its scoped context keys.
     * @param extraContext Extra context values to use when computing the contributions. Properties
     * in this object shadow (take precedence over) properties in the global context for this
     * computation.
     */
    getContributions<T>(scope?: IContributionScope | undefined): Observable<Evaluated<IContributions>>;
    /**
     * All contribution entries, emitted whenever the set of registered contributions changes.
     *
     * Most callers should use ContributionsRegistry#getContributions. Only use #entries if the
     * caller needs information that is discarded when the contributions are merged (such as the
     * extension that registered each set of contributions).
     */
    readonly entries: Observable<IContributionsEntry[]> & {
        value: IContributionsEntry[];
    };
}
